Apply codespell -w throughout
authorYaroslav Halchenko <debian@onerussian.com>
Tue, 14 Mar 2023 02:39:16 +0000 (22:39 -0400)
committerJoey Hess <joeyh@joeyh.name>
Fri, 17 Mar 2023 19:14:58 +0000 (15:14 -0400)
108 files changed:
Annex.hs
Annex/AdjustedBranch.hs
Annex/Branch.hs
Annex/ChangedRefs.hs
Annex/Content.hs
Annex/Content/Presence.hs
Annex/CopyFile.hs
Annex/Import.hs
Annex/Init.hs
Annex/Journal.hs
Annex/Locations.hs
Annex/NumCopies.hs
Annex/Path.hs
Annex/View/ViewedFile.hs
Annex/YoutubeDl.hs
Assistant/Alert/Utility.hs
Assistant/MakeRepo.hs
Assistant/Pairing/Network.hs
Assistant/Ssh.hs
Assistant/Sync.hs
Assistant/Threads/Committer.hs
Assistant/Threads/MountWatcher.hs
Assistant/Threads/NetWatcher.hs
Assistant/Threads/TransferWatcher.hs
Assistant/Types/RepoProblem.hs
Assistant/Unused.hs
Assistant/WebApp/Configurators/Ssh.hs
Assistant/WebApp/Control.hs
Assistant/WebApp/DashBoard.hs
Assistant/WebApp/SideBar.hs
Backend.hs
Backend/External.hs
Backend/Hash.hs
Build/LinuxMkLibs.hs
Build/OSXMkLibs.hs
CmdLine/GitAnnexShell.hs
Command/Assistant.hs
Command/CalcKey.hs
Command/Fsck.hs
Command/ImportFeed.hs
Command/Move.hs
Command/P2P.hs
Command/Sync.hs
Command/View.hs
Command/WebApp.hs
Crypto.hs
Database/Keys/SQL.hs
Git.hs
Git/GCrypt.hs
Git/LsFiles.hs
Git/PktLine.hs
Git/Queue.hs
Git/Remote.hs
Git/Repair.hs
Limit.hs
Logs/Chunk.hs
Logs/Export.hs
Logs/Export/Pure.hs
Logs/UUIDBased.hs
Logs/Unused.hs
Messages.hs
P2P/Protocol.hs
Remote.hs
Remote/Borg.hs
Remote/Bup.hs
Remote/Ddar.hs
Remote/Directory.hs
Remote/External.hs
Remote/External/AsyncExtension.hs
Remote/GitLFS.hs
Remote/Helper/ExportImport.hs
Remote/Helper/Ssh.hs
Remote/Rsync.hs
Remote/S3.hs
Remote/WebDAV.hs
Remote/WebDAV/DavLocation.hs
RemoteDaemon/Common.hs
RemoteDaemon/Types.hs
Test.hs
Test/Framework.hs
Types/Backend.hs
Types/Difference.hs
Types/FileMatcher.hs
Types/Import.hs
Types/Remote.hs
Upgrade/V5/Direct.hs
Utility/Base64.hs
Utility/Bloom.hs
Utility/Daemon.hs
Utility/DataUnits.hs
Utility/DirWatcher/FSEvents.hs
Utility/DirWatcher/Win32Notify.hs
Utility/Hash.hs
Utility/HtmlDetect.hs
Utility/IPAddress.hs
Utility/InodeCache.hs
Utility/LockFile/Windows.hs
Utility/LockPool/PidLock.hs
Utility/LockPool/Windows.hs
Utility/Matcher.hs
Utility/Misc.hs
Utility/Path.hs
Utility/Path/AbsRel.hs
Utility/Url.hs
Utility/Yesod.hs
doc/install/Android/git-annex-install
git-annex.cabal
templates/configurators/addia.hamlet

index 482c8455d4fb133f882504a70e5af82d972981a9..5a9eac3c32c6ec59f0fa14fe38f71e3c7241c980 100644 (file)
--- a/Annex.hs
+++ b/Annex.hs
@@ -400,7 +400,7 @@ addGitConfigOverride v = do
                        r { Git.gitGlobalOpts = go (Git.gitGlobalOpts r) }
        changeState $ \st -> st { gitconfigoverride = v : gitconfigoverride st }
   where
-       -- Remove any prior occurrance of the setting to avoid
+       -- Remove any prior occurrence of the setting to avoid
        -- building up many of them when the adjustment is run repeatedly,
        -- and add the setting to the end.
        go [] = [Param "-c", Param v]
index 9b35b8f71ba622722283832aadfddcbf51c91672..1907157e72c12009d04eabab66eb044aea8e1477 100644 (file)
@@ -460,7 +460,7 @@ findAdjustingCommit (AdjBranch b) = go =<< catCommit b
                        _ -> return Nothing
 
 {- Check for any commits present on the adjusted branch that have not yet
- - been propigated to the basis branch, and propigate them to the basis
+ - been propigated to the basis branch, and propagate them to the basis
  - branch and from there on to the orig branch.
  -
  - After propigating the commits back to the basis branch,
@@ -536,7 +536,7 @@ rebaseOnTopMsg = "rebasing adjusted branch on top of updated original branch"
 reverseAdjustedCommit :: Sha -> Adjustment -> (Sha, Commit) -> OrigBranch -> Annex (Either String Sha)
 reverseAdjustedCommit commitparent adj (csha, basiscommit) origbranch
        | length (commitParent basiscommit) > 1 = return $
-               Left $ "unable to propigate merge commit " ++ show csha ++ " back to " ++ show origbranch
+               Left $ "unable to propagate merge commit " ++ show csha ++ " back to " ++ show origbranch
        | otherwise = do
                cmode <- annexCommitMode <$> Annex.getGitConfig
                treesha <- reverseAdjustedTree commitparent adj csha
index 7f03f6bece65b5d841a0199962317480413b66ac..37bf6e3a6bce58e6e78e0370f2519d021575227f 100644 (file)
@@ -396,7 +396,7 @@ getRef ref file = withIndex $ catFile ref file
 {- Applies a function to modify the content of a file.
  -
  - Note that this does not cause the branch to be merged, it only
- - modifes the current content of the file on the branch.
+ - modifies the current content of the file on the branch.
  -}
 change :: Journalable content => RegardingUUID -> RawFilePath -> (L.ByteString -> content) -> Annex ()
 change ru file f = lockJournal $ \jl -> f <$> getToChange ru file >>= set jl ru file
@@ -422,7 +422,7 @@ data ChangeOrAppend t = Change t | Append t
  - value it provides is always appended to the journal file. That avoids
  - reading the journal file, and so can be faster when many lines are being
  - written to it. The information that is recorded will be effectively the
- - same, only obsolate log lines will not get compacted.
+ - same, only obsolete log lines will not get compacted.
  -
  - Currently, only appends when annex.alwayscompact=false. That is to
  - avoid appending when an older version of git-annex is also in use in the
@@ -494,7 +494,7 @@ append jl f appendable toappend = do
        invalidateCache
 
 {- Commit message used when making a commit of whatever data has changed
- - to the git-annex brach. -}
+ - to the git-annex branch. -}
 commitMessage :: Annex String
 commitMessage = fromMaybe "update" . annexCommitMessage <$> Annex.getGitConfig
 
@@ -624,7 +624,7 @@ branchFiles' = Git.Command.pipeNullSplit' $
 {- Populates the branch's index file with the current branch contents.
  - 
  - This is only done when the index doesn't yet exist, and the index 
- - is used to build up changes to be commited to the branch, and merge
+ - is used to build up changes to be committed to the branch, and merge
  - in changes from other branches.
  -}
 genIndex :: Git.Repo -> IO ()
index 83aa5561a7846fb433ecdcce19f3989e1bded8f1..7a9ce8a34f5377ca9e10e2cc2071a305e5baf39b 100644 (file)
@@ -106,6 +106,6 @@ notifyHook chan reffile _
                sha <- catchDefaultIO Nothing $
                        extractSha <$> S.readFile reffile
                -- When the channel is full, there is probably no reader
-               -- running, or ref changes have been occuring very fast,
+               -- running, or ref changes have been occurring very fast,
                -- so it's ok to not write the change to it.
                maybe noop (void . atomically . tryWriteTBMChan chan) sha
index 00907030475c4ea678f2f95b5c8944321bda9398..568077cabc50686c43e0013bd45ca2769a4438aa 100644 (file)
@@ -392,9 +392,9 @@ withTmp key action = do
  - with colliding files it's their own fault and B) adding such a check
  - would not catch all cases of colliding keys. For example, perhaps 
  - a remote has a key; if it's then added again with different content then
- - the overall system now has two different peices of content for that
+ - the overall system now has two different pieces of content for that
  - key, and one of them will probably get deleted later. So, adding the
- - check here would only raise expectations that git-annex cannot truely
+ - check here would only raise expectations that git-annex cannot truly
  - meet.
  -
  - May return false, when a particular variety of key is not being
@@ -555,7 +555,7 @@ sendAnnex key rollback sendobject = go =<< prepSendAnnex' key
 {- Returns a file that contains an object's content,
  - and a check to run after the transfer is complete.
  -
- - When a file is unlocked, it's possble for its content to
+ - When a file is unlocked, it's possible for its content to
  - change as it's being sent. The check detects this case
  - and returns False.
  -
index 52020a99027b2c68770e87896d08f90d390922c6..d3aea8715116410b6e335f0e5c83fbb412325a83 100644 (file)
@@ -164,7 +164,7 @@ contentLockFile :: Key -> Maybe RepoVersion -> Annex (Maybe RawFilePath)
 #ifndef mingw32_HOST_OS
 {- Older versions of git-annex locked content files themselves, but newer
  - versions use a separate lock file, to better support repos shared
- - amoung users in eg a group. -}
+ - among users in eg a group. -}
 contentLockFile key v
        | versionNeedsWritableContentFiles v = pure Nothing
        | otherwise = Just <$> calcRepo (gitAnnexContentLock key)
index 8fa84bddcb2e81ec2146b6e23397edc99db6ebac..9fc8eafc5350d6d1792f0bccc4d9c26c351357da 100644 (file)
@@ -66,7 +66,7 @@ data CopyMethod = CopiedCoW | Copied
 
 {- Copies from src to dest, updating a meter. Preserves mode and mtime.
  - Uses copy-on-write if it is supported. If the the destination already
- - exists, an interruped copy will resume where it left off.
+ - exists, an interrupted copy will resume where it left off.
  -
  - The IncrementalVerifier is updated with the content of the file as it's
  - being copied. But it is not finalized at the end.
index c16eb1821382ebd2a6582b30278be445600a12a3..6f398564c25cbaa2d1a4b503f99c7b729a188f83 100644 (file)
@@ -492,7 +492,7 @@ importKeys remote importtreeconfig importcontent thirdpartypopulated importablec
        startimport cidmap importing db i@(loc, (cid, _sz)) oldversion largematcher = getcidkey cidmap db cid >>= \case
                (k:ks) ->
                        -- If the same content was imported before
-                       -- yeilding multiple different keys, it's not clear
+                       -- yielding multiple different keys, it's not clear
                        -- which is best to use this time, so pick the
                        -- first in the list. But, if any of them is a
                        -- git sha, use it, because the content must
index b152f46aa589f12de9c11266130893bad30ba12f..1220c2e58ea199c050777928b2c347113a23d626 100644 (file)
@@ -421,7 +421,7 @@ initSharedClone True = do
        trustSet u UnTrusted
        setConfig (annexConfig "hardlink") (Git.Config.boolConfig True)
 
-{- Propigate annex.securehashesonly from then global config to local
+{- Propagate annex.securehashesonly from then global config to local
  - config. This makes a clone inherit a parent's setting, but once
  - a repository has a local setting, changes to the global config won't
  - affect it. -}
index f2d3738f731b997e6ffd40aeb023706e1dd6b0c1..ce0f26e63e154d6ada3407fd26bff0fbfbf1cca2 100644 (file)
@@ -73,7 +73,7 @@ privateUUIDsKnown' = not . S.null . annexPrivateRepos . Annex.gitconfig
 
 {- Records content for a file in the branch to the journal.
  -
- - Using the journal, rather than immediatly staging content to the index
+ - Using the journal, rather than immediately staging content to the index
  - avoids git needing to rewrite the index after every change.
  - 
  - The file in the journal is updated atomically. This avoids an
index e8361b377e890ad76aadf30d2f0f3bf752fe9b36..c8ddc5cc96f0cf515420ae63f5526dbe8fb946c3 100644 (file)
@@ -580,7 +580,7 @@ gitAnnexAssistantDefaultDir = "annex"
  - dealing with characters that cause problems.
  -
  - This is used when a new Key is initially being generated, eg by genKey.
- - Unlike keyFile and fileKey, it does not need to be a reversable
+ - Unlike keyFile and fileKey, it does not need to be a reversible
  - escaping. Also, it's ok to change this to add more problematic
  - characters later. Unlike changing keyFile, which could result in the
  - filenames used for existing keys changing and contents getting lost.
@@ -666,7 +666,7 @@ keyPath key hasher = hasher key P.</> f P.</> f
   where
        f = keyFile key
 
-{- All possibile locations to store a key in a special remote
+{- All possible locations to store a key in a special remote
  - using different directory hashes.
  -
  - This is compatible with the annexLocationsNonBare and annexLocationsBare,
index 9988b2052f0ba8dc713529ed3480e7bafb356056..bcab47d1b6e26bed667eeda4b0c5e2863c80f95a 100644 (file)
@@ -203,7 +203,7 @@ numCopiesCheck' file vs have = do
 data UnVerifiedCopy = UnVerifiedRemote Remote | UnVerifiedHere
        deriving (Ord, Eq)
 
-{- Verifies that enough copies of a key exist amoung the listed remotes,
+{- Verifies that enough copies of a key exist among the listed remotes,
  - to safely drop it, running an action with a proof if so, and
  - printing an informative message if not.
  -}
index e058db32a88f62f460e5c211ae6717e5c2a7a702..aa51da1b58f65941f4572f06a6856fa309dfcb3c 100644 (file)
@@ -95,7 +95,7 @@ gitAnnexGitConfigOverrides = concatMap (\c -> [Param "-c", Param c])
  - to daemonize it. Used with Utility.Daemon.daemonize. -}
 gitAnnexDaemonizeParams :: Annex [CommandParam]
 gitAnnexDaemonizeParams = do
-       -- This inclues -c parameters passed to git, as well as ones
+       -- This includes -c parameters passed to git, as well as ones
        -- passed to git-annex.
        cps <- gitAnnexGitConfigOverrides
        -- Get every parameter git-annex was run with.
index e211c621ed2149fd01f7a64ac17abadfccee4655..c804a50c0b02eb4aaa8e4728c1c8c0246c715a47 100644 (file)
@@ -29,7 +29,7 @@ type MkViewedFile = FilePath -> ViewedFile
 {- Converts a filepath used in a reference branch to the
  - filename that will be used in the view.
  -
- - No two filepaths from the same branch should yeild the same result,
+ - No two filepaths from the same branch should yield the same result,
  - so all directory structure needs to be included in the output filename
  - in some way.
  -
index 854acb9dadbffc7889bfa2d558abe135da73ad25..1dd0d56ec8478fe89950f8528e8e96ad05d24ddd 100644 (file)
@@ -58,7 +58,7 @@ youtubeDlNotAllowedMessage = unwords
 -- and youtube-dl needs to finish up with only one file in the directory
 -- so we know which one it downloaded.
 --
--- (Note that we can't use --output to specifiy the file to download to,
+-- (Note that we can't use --output to specify the file to download to,
 -- due to <https://github.com/rg3/youtube-dl/issues/14864>)
 youtubeDl :: URLString -> FilePath -> MeterUpdate -> Annex (Either String (Maybe FilePath))
 youtubeDl url workdir p = ifM ipAddressesUnlimited
index a864edb0f88fa048af7f2948833fb78fa1f874a3..8016d620a4160adf6baad4f3c62ffbe4805f5f84 100644 (file)
@@ -35,7 +35,7 @@ type AlertPair = (AlertId, Alert)
  - - High priority alerts, newest first
  - - Medium priority Activity, newest first (mostly used for Activity)
  - - Low priority alerts, newest first
- - - Filler priorty alerts, newest first
+ - - Filler priority alerts, newest first
  - - Ties are broken by the AlertClass, with Errors etc coming first.
  -}
 compareAlertPairs :: AlertPair -> AlertPair -> Ordering
index 06a0a659d01da5042344a5f2d1760e1e3b761263..e87701f32b9435704774a31fcb5f76f1cfc2a4d0 100644 (file)
@@ -68,7 +68,7 @@ initRepo True primary_assistant_repo dir desc mgroup = inDir dir $ do
        {- Repositories directly managed by the assistant use 
         - an adjusted unlocked branch with annex.thin set.
         - 
-        - Automatic gc is disabled, as it can be slow. Insted, gc is done
+        - Automatic gc is disabled, as it can be slow. Instead, gc is done
         - once a day.
         -}
        when primary_assistant_repo $ do
index 944007f0152da6a65a33413c7f199dd3601a696d..62a4ea02e80827b41a0213ddb9c6c40f53bd42c1 100644 (file)
@@ -27,7 +27,7 @@ import Control.Concurrent
 
 {- This is an arbitrary port in the dynamic port range, that could
  - conceivably be used for some other broadcast messages.
- - If so, hope they ignore the garbage from us; we'll certianly
+ - If so, hope they ignore the garbage from us; we'll certainly
  - ignore garbage from them. Wild wild west. -}
 pairingPort :: PortNumber
 pairingPort = 55556
index 3826f5e70e25538ddffb0294c75519d591ed4b25..c392d54eb8eafe55522d38fc50d141f5ae040c6a 100644 (file)
@@ -361,7 +361,7 @@ setSshConfig sshdata config = do
  - non-alphanumerics, other than "_"
  -
  - The real hostname is not normally encoded at all. This is done for
- - backwards compatability and to avoid unnecessary ugliness in the
+ - backwards compatibility and to avoid unnecessary ugliness in the
  - filename. However, when it contains special characters
  - (notably ":" which cannot be used on some filesystems), it is url
  - encoded. To indicate it was encoded, the mangled hostname
index 4bd3f8d7fffdd1bcfe8ceff5ea0584ceb39119be..c7907d777c11187cc790bb0e728a98fef7fca0cf 100644 (file)
@@ -107,7 +107,7 @@ reconnectRemotes rs = void $ do
  - When there's a lot of activity, we may fail more than once.
  - On the other hand, we may fail because the remote is not available.
  - Rather than retrying indefinitely, after the first retry we enter a
- - fallback mode, where our push is guarenteed to succeed if the remote is
+ - fallback mode, where our push is guaranteed to succeed if the remote is
  - reachable. If the fallback fails, the push is queued to be retried
  - later.
  -
index 2e9a25c1114781fb420ebe82c52507fde14f9ff6..b75111a3826104439b0ef7230954d0e31ef31c18 100644 (file)
@@ -95,7 +95,7 @@ refill cs = do
  - runs an action to commit them. If more changes arrive while this is
  - going on, they're handled intelligently, batching up changes into
  - large commits where possible, doing rename detection, and
- - commiting immediately otherwise. -}
+ - committing immediately otherwise. -}
 waitChangeTime :: (([Change], UTCTime) -> Assistant Int) -> Assistant ()
 waitChangeTime a = waitchanges 0
   where
index 566e9db78d37377d9cab22759e32d14a6c48747c..7a59018bcb1b55464726948b277711a43d1b06d2 100644 (file)
@@ -111,7 +111,7 @@ startOneService client (x:xs) = do
                , startOneService client xs
                )
 
-{- Filter matching events recieved when drives are mounted and unmounted. -}   
+{- Filter matching events received when drives are mounted and unmounted. -}   
 mountChanged :: [MatchRule]
 mountChanged = [udisks2mount, udisks2umount]
   where
index 59b1da5f370013d19174bf81c47893cd4a0fff0e..7d4b6cc1387458701f3909b3abb5ab417ef90ebf 100644 (file)
@@ -163,9 +163,9 @@ listenNMConnections client setconnected =
  -   ConnectResultsSent:
  -     Variant "success"
  -
- - Diconnection example:
+ - Disconnection example:
  -   StatusChanged
- -     [Variant 0, Variant [Varient ""]]
+ -     [Variant 0, Variant [Variant ""]]
  -}
 listenWicdConnections :: Client -> (Bool -> IO ()) -> IO ()
 listenWicdConnections client setconnected = do
index c4d743ea2b3362fed1d85356776c8f5571408c39..43f892e38ea1eaafeb5f4c0a0d7e24f1486872e0 100644 (file)
@@ -80,7 +80,7 @@ onModify file = case parseTransferFile file of
                \i -> i { bytesComplete = bytesComplete newinfo }
 
 {- This thread can only watch transfer sizes when the DirWatcher supports
- - tracking modificatons to files. -}
+ - tracking modifications to files. -}
 watchesTransferSize :: Bool
 watchesTransferSize = modifyTracked
 
index 16128d0d81ead9e6cbea1c3aa163e32327639cd9..afc7e4b2f3fd14a5c164223b83ce3ce0275c410e 100644 (file)
@@ -18,7 +18,7 @@ data RepoProblem = RepoProblem
        , afterFix :: IO ()
        }
 
-{- The afterFix actions are assumed to all be equivilant. -}
+{- The afterFix actions are assumed to all be equivalent. -}
 sameRepoProblem :: RepoProblem -> RepoProblem -> Bool
 sameRepoProblem = (==) `on` problemUUID
 
index d91299e2e5c64991f63dba2ab636060d012bdbe9..8af61527d2a62a681054c94a9ec4824779788ef5 100644 (file)
@@ -79,7 +79,7 @@ expireUnused duration = do
                        lockContentForRemoval k noop removeAnnex
                        logStatus k InfoMissing
   where
-       boundry = durationToPOSIXTime <$> duration
-       tooold now (_, mt) = case boundry of
+       boundary = durationToPOSIXTime <$> duration
+       tooold now (_, mt) = case boundary of
                Nothing -> True
                Just b -> maybe False (\t -> now - t >= b) mt
index 661ab95d1dd12a5b1a3a80484e79cf9302114033..86065b8fc48eae0bf494556d3ca69ddf09e1e515 100644 (file)
@@ -642,7 +642,7 @@ enableRsyncNetGCrypt sshinput reponame =
  - used on rsync.net. If successful, runs an action with its SshData.
  -
  - To append the ssh key to rsync.net's authorized_keys, their
- - documentation recommends a dd methodd, where the line is fed
+ - documentation recommends a dd method, where the line is fed
  - in to ssh over stdin.
  -}
 prepRsyncNet :: SshInput -> String -> (SshData -> Handler Html) -> Handler Html
index af248a904677ad02bd68865e6aeada4efbdb2ad5..5d60731bfe6cbac6e912360993421619df11a7cd 100644 (file)
@@ -52,7 +52,7 @@ getShutdownConfirmedR = do
 
 {- Use a custom page to avoid putting long polling elements on it that will 
  - fail and cause thet web browser to show an error once the webapp is
- - truely stopped. -}
+ - truly stopped. -}
 getNotRunningR :: Handler Html
 getNotRunningR = customPage' False Nothing $
        $(widgetFile "control/notrunning")
index 1bc7c316dfec84d7f7fab2edf43940dbd749bda5..5bbcee3c92714cfe9a7055a4fb240575e2534b9a 100644 (file)
@@ -48,7 +48,7 @@ transfersDisplay = do
                AssociatedFile (Just af) -> fromRawFilePath af
 
 {- Simplifies a list of transfers, avoiding display of redundant
- - equivilant transfers. -}
+ - equivalent transfers. -}
 simplifyTransfers :: [(Transfer, TransferInfo)] -> [(Transfer, TransferInfo)]
 simplifyTransfers [] = []
 simplifyTransfers (x:[]) = [x]
index 51279f24a252cae4aedf7b5b70a48acc26a69ca7..aae063d7c45e3d1c64a88c780118185883aeac4b 100644 (file)
@@ -66,7 +66,7 @@ getSideBarR nid = do
        waitNotifier getAlertBroadcaster nid
 
        {- This 0.1 second delay avoids very transient notifications from
-        - being displayed and churning the sidebar unnecesarily. 
+        - being displayed and churning the sidebar unnecessarily. 
         -
         - This needs to be below the level perceptable by the user,
         - to avoid slowing down user actions like closing alerts. -}
index 8e49bfce413e6296e6f1b1efd59e030658ef803f..d3eb9414dd7b5b67208f1f1cda65eeb095fb8a30 100644 (file)
@@ -34,7 +34,7 @@ import qualified Backend.External
 
 import qualified Data.Map as M
 
-{- Build-in backends. Does not include externals. -}
+{- Built-in backends. Does not include externals. -}
 builtinList :: [Backend]
 builtinList = Backend.Hash.backends ++ Backend.WORM.backends ++ Backend.URL.backends
 
index fe7449f1f97d9b863795eb4959cbaddf8f036322..5ee7150c7200ee45d8c83f5000441e9a01900a40 100644 (file)
@@ -158,7 +158,7 @@ sendMessage p m = liftIO $ do
   where
        line = unwords $ Proto.formatMessage m
 
-{- A response handler can yeild a result, or it can request that another
+{- A response handler can yield a result, or it can request that another
  - message be consumed from the external. -}
 data ResponseHandlerResult a
        = Result a
@@ -170,7 +170,7 @@ result :: a -> Maybe (Annex (ResponseHandlerResult a))
 result = Just . return . Result
 
 {- Waits for a message from the external backend, and passes it to the
- - apppropriate handler. 
+ - appropriate handler. 
  -
  - If the handler returns Nothing, this is a protocol error.
  -}
index 550d8fc6c06da36fa48cf00a9d2fa5407c43ab62..314b2676e2d1be423eb3dcb03bc08af873a07a7b 100644 (file)
@@ -281,7 +281,7 @@ md5Hasher = mkHasher md5 md5_context
 descChecksum :: String
 descChecksum = "checksum"
 
-{- A varient of the SHA256E backend, for testing that needs special keys
+{- A variant of the SHA256E backend, for testing that needs special keys
  - that cannot collide with legitimate keys in the repository.
  -
  - This is accomplished by appending a special extension to the key,
index 33357909e685d540ecfd18809a90dbed5bcc85af..44cc32cb30903cdba825b05fbd252ce980dcff42 100644 (file)
@@ -55,7 +55,7 @@ mklibs top _installedbins = do
   where
        -- hwcap lib dirs are things like foo/tls and foo/x86.
        -- Hard to know if a directory is, so this is a heuristic
-       -- looking for things that are certianly not. If this heuristic
+       -- looking for things that are certainly not. If this heuristic
        -- fails, a minor optimisation will not happen, but there will be
        -- no bad results.
        hwcaplibdir d = not $ or
index aadd9519ed3f131344477c30a2b94c2d2b79dc3b..f0e8a91d9d05534c6659f3f8b5118176f7b9d044 100644 (file)
@@ -104,7 +104,7 @@ otool appbase installedbins replacement_libs libmap = do
                -- ImageIO.framework uses libPng which is built against a
                -- specific version of libz; other versions lack the
                -- _inflateValidate symbol. So, avoid bundling libz unless
-               -- this incompatability is resolved.
+               -- this incompatibility is resolved.
                && not ("libz." `isInfixOf` s)
        lib_present s
                | "@rpath" `isInfixOf` s = return True
index b3dd4e67749fe5c4d78f267385ca7c4a6d52bc06..f7e65374b852cdb365147140cbc8b4f5b6001608 100644 (file)
@@ -40,7 +40,7 @@ cmdsMap = M.fromList $ map mk
        readonlycmds = map addAnnexOptions
                [ Command.ConfigList.cmd
                , gitAnnexShellCheck Command.NotifyChanges.cmd
-               -- p2pstdio checks the enviroment variables to
+               -- p2pstdio checks the environment variables to
                -- determine the security policy to use
                , gitAnnexShellCheck Command.P2PStdIO.cmd
                , gitAnnexShellCheck Command.InAnnex.cmd
index 2a9bfc988766e609418d0ec1fde732591535c449..b999e5b2719a2ef1462b1e1a0674f523bb8bd321 100644 (file)
@@ -94,7 +94,7 @@ autoStart o = do
                                                , putStrLn "failed"
                                                )
                                return Nothing
-       -- Wait for any foreground jobs to finish and propigate exit status.
+       -- Wait for any foreground jobs to finish and propagate exit status.
        ifM (all (== True) <$> mapConcurrently checkSuccessProcess (catMaybes pids))
                ( exitSuccess
                , exitFailure
index 82d3c4c6181187b76a1dee9e6d54baf19f1e381b..b44a2df0cf734a8bf4186d4c3f4e0eb13993f605 100644 (file)
@@ -16,7 +16,7 @@ cmd :: Command
 cmd = noCommit $ noMessages $ dontCheck repoExists $
        withAnnexOptions [backendOption] $
                command "calckey" SectionPlumbing 
-                       "calulate key for a file"
+                       "calculate key for a file"
                        (paramRepeating paramFile)
                        (batchable run (pure ()))
 
index e0b357fcbc54b793f45ac57e56d84088784478b1..dd48c986805b88101a5729cd7889778aa772c1c0 100644 (file)
@@ -667,7 +667,7 @@ recordFsckTime inc key = withFsckDb inc $ \h -> liftIO $ FsckDb.addDb h key
 
 {- Records the start time of an incremental fsck.
  -
- - To guard against time stamp damange (for example, if an annex directory
+ - To guard against time stamp damage (for example, if an annex directory
  - is copied without -a), the fsckstate file contains a time that should
  - be identical to its modification time.
  - (This is not possible to do on Windows, and so the timestamp in
index 1a874408a70cb030c71b92746dea4f7ae83d7daa..2146dadc5f10fcc5f1185f19c01cf3f7a4d4d7ba 100644 (file)
@@ -519,7 +519,7 @@ feedState url = fromRepo $ gitAnnexFeedState $ fromUrl url Nothing
  -
  - So, it's not safe to use T.unpack to convert that to a String,
  - because later use of that String by eg encodeBS will crash
- - with an encoding error. Use this instad.
+ - with an encoding error. Use this instead.
  -
  - This should not be used on a Text that is read using the
  - filesystem encoding because it does not reverse that encoding.
index 925b4e45d9ce2cf70adbcdacfad73ad9f6ff736e..96f1b5c6a7e4b4e8bab403bdd278e25bb16c9c32 100644 (file)
@@ -356,7 +356,7 @@ fromToStart removewhen afile key ai si src dest = do
  - drop the local copy, and finally drop from the src.
  -
  - Using a regular download of the local copy, rather than download to
- - some other file makes resuming an interruped download work as usual,
+ - some other file makes resuming an interrupted download work as usual,
  - and simplifies implementation. It does mean that, if `git-annex get` of
  - the same content is being run at the same time as this move, the content
  - may end up locally present, or not. This is similar to the behavior 
index ded64e0ab91896ae5a8f17052087086898543b68..a702648d3e91f354c48ee28b20734f8ae9f43ed2 100644 (file)
@@ -87,7 +87,7 @@ unusedPeerRemoteName = go (1 :: Integer) =<< usednames
 
 -- Only addresses are output to stdout, to allow scripting.
 genAddresses :: [P2PAddress] -> Annex ()
-genAddresses [] = giveup "No P2P networks are currrently available."
+genAddresses [] = giveup "No P2P networks are currently available."
 genAddresses addrs = do
        authtoken <- liftIO $ genAuthToken 128
        storeP2PAuthToken authtoken
@@ -124,7 +124,7 @@ linkRemote remotename = starting "p2p link" ai si $
                                                AuthenticationError e -> giveup e
 
 startPairing :: RemoteName -> [P2PAddress] -> CommandStart
-startPairing _ [] = giveup "No P2P networks are currrently available."
+startPairing _ [] = giveup "No P2P networks are currently available."
 startPairing remotename addrs = ifM (liftIO Wormhole.isInstalled)
        ( starting "p2p pair" ai si $
                performPairing remotename addrs
index 595d8f12b9dd5aa6cf4b15d00b7610f45ffc3d9c..21f0df45ba840d0a2d9aef54a27f8783c540dd52 100644 (file)
@@ -454,7 +454,7 @@ updateBranches (Just branch, madj) = do
                                case madj' of
                                        Nothing -> noop
                                        Just adj -> updateadjustedbranch adj
-               -- When in an adjusted branch, propigate any changes
+               -- When in an adjusted branch, propagate any changes
                -- made to it back to the original branch.
                Nothing -> case madj of
                        Just adj -> do
@@ -739,7 +739,7 @@ newer remote b = do
                )
 
 {- Without --all, only looks at files in the work tree.
- - (Or, when in an ajusted branch where some files are hidden, at files in
+ - (Or, when in an adjusted branch where some files are hidden, at files in
  - the original branch.)
  -
  - With --all, when preferred content expressions look at filenames,
index 4a00d20fe0d31db98cf2d0748ae04a950249a8ad..60ec89053704cb3394645a38c01808cf18ff2df2 100644 (file)
@@ -110,7 +110,7 @@ checkoutViewBranch view madj mkbranch = do
                setView view
                {- A git repo can easily have empty directories in it,
                 - and this pollutes the view, so remove them.
-                - (However, emptry directories used by submodules are not
+                - (However, empty directories used by submodules are not
                 - removed.) -}
                top <- liftIO . absPath =<< fromRepo Git.repoPath
                (l, cleanup) <- inRepo $
index 1e01e1a97f48e18de89d572e468eb9d6a1b6b083..ac0f9d3419ec3a26cbac57d3189727d743bd1728 100644 (file)
@@ -103,7 +103,7 @@ start' allowauto o = do
                liftIO $ firstRun o
 
 {- If HOME is a git repo, even if it's initialized for git-annex,
- - the user almost certianly does not want to run the assistant there. -}
+ - the user almost certainly does not want to run the assistant there. -}
 notHome :: Annex Bool
 notHome = do
        g <- Annex.gitRepo
index 6750284ee1b3beb0e1fadce7d60fee47aef0e501..41d4789d7fd31f63135d088b9639e2d743235a49 100644 (file)
--- a/Crypto.hs
+++ b/Crypto.hs
@@ -1,7 +1,7 @@
 {- git-annex crypto
  -
  - Currently using gpg; could later be modified to support different
- - crypto backends if neccessary.
+ - crypto backends if necessary.
  -
  - Copyright 2011-2022 Joey Hess <id@joeyh.name>
  -
@@ -62,7 +62,7 @@ import qualified Data.ByteString.Short as S (toShort)
  - (ideally) 64 and 128 bytes of entropy.
  -
  - The remaining characters (320 bytes of entropy) is enough for GnuPG's
- - symetric cipher; unlike weaker public key crypto, the key does not
+ - symmetric cipher; unlike weaker public key crypto, the key does not
  - need to be too large.
  -}
 cipherBeginning :: Int
@@ -164,7 +164,7 @@ decryptCipher' cmd environ c (EncryptedCipher t variant _) =
 type EncKey = Key -> Key
 
 {- Generates an encrypted form of a Key. The encryption does not need to be
- - reversable, nor does it need to be the same type of encryption used
+ - reversible, nor does it need to be the same type of encryption used
  - on content. It does need to be repeatable. -}
 encryptKey :: Mac -> Cipher -> EncKey
 encryptKey mac c k = mkKey $ \d -> d
index 0ebeaf7f4fd3dc275c405fcaf1e5c1cba9d622c2..c97a4280b925ec2e2d7a9c6d0c5893a0b2b663aa 100644 (file)
@@ -33,7 +33,7 @@ import Data.Maybe
 -- Note on indexes: KeyFileIndex etc are really uniqueness constraints,
 -- which cause sqlite to automatically add indexes. So when adding indexes,
 -- have to take care to only add ones that work as uniqueness constraints.
--- (Unfortunatly persistent does not support indexes that are not
+-- (Unfortunately persistent does not support indexes that are not
 -- uniqueness constraints; https://github.com/yesodweb/persistent/issues/109)
 --
 -- To speed up queries for a key, there's KeyFileIndex, 
diff --git a/Git.hs b/Git.hs
index 37b2f4420ee4facc3218df28d0f343e50bac8c10..5e0b6980b27cb42ab8ff1d4f0bde91348f43480e 100644 (file)
--- a/Git.hs
+++ b/Git.hs
@@ -1,6 +1,6 @@
 {- git repository handling 
  -
- - This is written to be completely independant of git-annex and should be
+ - This is written to be completely independent of git-annex and should be
  - suitable for other uses.
  -
  - Copyright 2010-2021 Joey Hess <id@joeyh.name>
@@ -79,7 +79,7 @@ repoPath Repo { location = Local { worktree = Just d } } = d
 repoPath Repo { location = Local { gitdir = d } } = d
 repoPath Repo { location = LocalUnknown dir } = dir
 repoPath Repo { location = Unknown } = error "unknown repoPath"
-repoPath Repo { location = UnparseableUrl _u } = error "unknwon repoPath"
+repoPath Repo { location = UnparseableUrl _u } = error "unknown repoPath"
 
 repoWorkTree :: Repo -> Maybe RawFilePath
 repoWorkTree Repo { location = Local { worktree = Just d } } = Just d
index c7e5df47f0c6d49dec91055bb31e21bbbbcf13f4..072598b755db89cf9e245226f638588e3a46f10c 100644 (file)
@@ -85,7 +85,7 @@ probeRepo loc baserepo = do
 
 type GCryptId = String
 
-{- gcrypt gives each encrypted repository a uique gcrypt-id,
+{- gcrypt gives each encrypted repository a unique gcrypt-id,
  - which is stored in the repository (in encrypted form)
  - and cached in a per-remote gcrypt-id configuration setting. -}
 remoteRepoId :: Repo -> Maybe RemoteName -> Maybe GCryptId
index cc824f2641c826ef0c5e46304f1e35937447a85e..4eea39541a3ec824149fe81ca7c101673fbc827d 100644 (file)
@@ -325,7 +325,7 @@ reduceUnmerged c (i:is) = reduceUnmerged (new:c) rest
                && isus x || isus y
                && not (isus x && isus y)
 
-{- Gets the InodeCache equivilant information stored in the git index.
+{- Gets the InodeCache equivalent information stored in the git index.
  -
  - Note that this uses a --debug option whose output could change at some
  - point in the future. If the output is not as expected, will use Nothing.
index 32509bd9a8183dc72934a77658280c124e5704fe..a49cfc2b63e6735900a60984d38dcf2c658ad71d 100644 (file)
@@ -33,7 +33,7 @@ import Utility.PartialPrelude
 import Utility.FileSystemEncoding
 
 {- This is a variable length binary string, but its size is limited to
- - maxPktLineLength. Its serialization includes a 4 byte hexidecimal
+ - maxPktLineLength. Its serialization includes a 4 byte hexadecimal
  - prefix giving its total length, including that prefix. -}
 newtype PktLine = PktLine B.ByteString
        deriving (Show)
index dd77b35bf09f0de1f8058a383d571008e84dd798..156ed8c95a16ea378b5e783b352013b4b9c81a60 100644 (file)
@@ -119,7 +119,7 @@ new lim tlim = do
 {- Adds an git command to the queue.
  -
  - Git commands with the same subcommand but different parameters are
- - assumed to be equivilant enough to perform in any order with the same
+ - assumed to be equivalent enough to perform in any order with the same
  - end result.
  -}
 addCommand :: MonadIO m => [CommandParam] -> String -> [CommandParam] -> [FilePath] -> Queue m -> Repo -> m (Queue m)
index 80acccaf4c853bbd9674ddcecd581a6480da108d..e6036a7b2cb392a856fed366e093603ee1eba979 100644 (file)
@@ -43,7 +43,7 @@ remoteKeyToRemoteName (ConfigKey k)
 {- Construct a legal git remote name out of an arbitrary input string.
  -
  - There seems to be no formal definition of this in the git source,
- - just some ad-hoc checks, and some other things that fail with certian
+ - just some ad-hoc checks, and some other things that fail with certain
  - types of names (like ones starting with '-').
  -}
 makeLegalName :: String -> RemoteName
index 601b32291ae7da2c31cbf5dc143ca6317825d7c1..9638187a761ebe4237358de4629b67187d02f92f 100644 (file)
@@ -103,7 +103,7 @@ explodePacks r = go =<< listPackFiles r
                return True
 
 {- Try to retrieve a set of missing objects, from the remotes of a
- - repository. Returns any that could not be retreived.
+ - repository. Returns any that could not be retrieved.
  -
  - If another clone of the repository exists locally, which might not be a
  - remote of the repo being repaired, its path can be passed as a reference
index 9cb9ac2feb49e1642629ee54543ca7f1dfe68e14..19a71185e3c09829d8f1cfb3d603a4d881415a14 100644 (file)
--- a/Remote.hs
+++ b/Remote.hs
@@ -99,7 +99,7 @@ remoteMap' mkv mkk = M.fromList . catMaybes <$> (mapM mk =<< remoteList)
                Just k -> Just (k, mkv r)
 
 {- Map of UUIDs of repositories and their descriptions.
- - The names of Remotes are added to suppliment any description that has
+ - The names of Remotes are added to supplement any description that has
  - been set for a repository.  -}
 uuidDescriptions :: Annex UUIDDescMap
 uuidDescriptions = M.unionWith addName
index 30414db79e64d5ffb021e8dae5e676c7d19d7fe1..d3b152c8020d0d6369cf1ea4358c9ef07eafd620 100644 (file)
@@ -141,7 +141,7 @@ borgSetup _ mu _ c _gc = do
                M.lookup borgrepoField c
 
        -- The borgrepo is stored in git config, as well as this repo's
-       -- persistant state, so it can vary between hosts.
+       -- persistent state, so it can vary between hosts.
        gitConfigSpecialRemote u c [("borgrepo", borgrepo)]
 
        return (c, u)
index b2c11dece4ec5fdae4b0f60f7ee0f6e23446be26..8bcacf9b94846821d6744af9fd0ab7e267751481 100644 (file)
@@ -137,7 +137,7 @@ bupSetup _ mu _ c gc = do
        storeBupUUID u buprepo
 
        -- The buprepo is stored in git config, as well as this repo's
-       -- persistant state, so it can vary between hosts.
+       -- persistent state, so it can vary between hosts.
        gitConfigSpecialRemote u c' [("buprepo", buprepo)]
 
        return (c', u)
index 37b6d03c1f5a8adedfb9393a4969e17bd1b45902..75d93e6a18102091526696e46807ade755976007 100644 (file)
@@ -120,7 +120,7 @@ ddarSetup _ mu _ c gc = do
        (c', _encsetup) <- encryptionSetup c gc
 
        -- The ddarrepo is stored in git config, as well as this repo's
-       -- persistant state, so it can vary between hosts.
+       -- persistent state, so it can vary between hosts.
        gitConfigSpecialRemote u c' [("ddarrepo", ddarrepo)]
 
        return (c', u)
index d495d42fdd2d00937c44a1e8ed9354ca67a34b68..5721bd20fab97e8a3b890be2ac02aee6db8cf17e 100644 (file)
@@ -153,7 +153,7 @@ directorySetup _ mu _ c gc = do
        (c', _encsetup) <- encryptionSetup c gc
 
        -- The directory is stored in git config, not in this remote's
-       -- persistant state, so it can vary between hosts.
+       -- persistent state, so it can vary between hosts.
        gitConfigSpecialRemote u c' [("directory", absdir)]
        return (M.delete directoryField c', u)
 
index 83f1b0410b1fbebad49593d9a6935001ff290bc6..4077030fa3a5013e3eefb1a3bc11d22fca0c7335 100644 (file)
@@ -536,7 +536,7 @@ receiveMessageAddonProcess p = do
 shutdownAddonProcess :: AddonProcess.ExternalAddonProcess -> Bool -> IO ()
 shutdownAddonProcess = AddonProcess.externalShutdown 
 
-{- A response handler can yeild a result, or it can request that another
+{- A response handler can yield a result, or it can request that another
  - message be consumed from the external. -}
 data ResponseHandlerResult a
        = Result a
@@ -548,7 +548,7 @@ result :: a -> Maybe (Annex (ResponseHandlerResult a))
 result = Just . return . Result
 
 {- Waits for a message from the external remote, and passes it to the
- - apppropriate handler. 
+ - appropriate handler. 
  -
  - If the handler returns Nothing, this is a protocol error.-}
 receiveMessage
index fd88349a45cdb4f66a53a4b097f999658dffaf29..177249c1cb73b21ef84c065d57524c8cbd97ecdc 100644 (file)
@@ -46,7 +46,7 @@ runRelayToExternalAsync external st annexrunner = do
                        , externalReceive = atomically (readTBMChan receiveq)
                        -- This shuts down the whole relay.
                        , externalShutdown = shutdown external st sendq sender receiver
-                       -- These three TMVars are shared amoung all
+                       -- These three TMVars are shared among all
                        -- ExternalStates that use this relay; they're
                        -- common state about the external process.
                        , externalPrepared = externalPrepared st
index 0ad4a63f7d80d1ddbaabddb3093a94afdccb9fa1..621089f203f3eff5b54b542c991915e494951df0 100644 (file)
@@ -84,7 +84,7 @@ urlField = Accepted "url"
 gen :: Git.Repo -> UUID -> RemoteConfig -> RemoteGitConfig -> RemoteStateHandle -> Annex (Maybe Remote)
 gen r u rc gc rs = do
        c <- parsedRemoteConfig remote rc
-       -- If the repo uses gcrypt, get the underlaying repo without the
+       -- If the repo uses gcrypt, get the underlying repo without the
        -- gcrypt url, to do LFS endpoint discovery on.
        r' <- if Git.GCrypt.isEncrypted r
                then do
index 1d71ae70d110e423ae4ba63d8336ebe7212e3829..987256eb9a3d5e5b9a11441cb73ffddbb1ef3d8b 100644 (file)
@@ -212,7 +212,7 @@ adjustExportImport' isexport isimport r rs = do
                -- ones though, since they still allow accessing by Key.
                -- And for thirdPartyPopulated, it depends on how the
                -- content gets actually stored in the remote, so
-               -- is not overriddden here.
+               -- is not overridden here.
                , untrustworthy =
                        if versioned || thirdPartyPopulated (remotetype r)
                                then untrustworthy r
@@ -235,7 +235,7 @@ adjustExportImport' isexport isimport r rs = do
   where
        thirdpartypopulated = thirdPartyPopulated (remotetype r)
 
-       -- exportActions adjusted to use the equivilant import actions,
+       -- exportActions adjusted to use the equivalent import actions,
        -- which take ContentIdentifiers into account.
        exportActionsForImport dbv ciddbv ea = ea
                { storeExport = \f k loc p -> do
index 32287b7c14f98041f7bdab7a189e0fa4c5ea3016..c71a67ac6456efbfd8c870e8b9c46eda3b1b7ecf 100644 (file)
@@ -151,7 +151,7 @@ rsyncParamsRemote r direction key file = do
        {- The rsync shell parameter controls where rsync
         - goes, so the source/dest parameter can be a dummy value,
         - that just enables remote rsync mode.
-        - For maximum compatability with some patched rsyncs,
+        - For maximum compatibility with some patched rsyncs,
         - the dummy value needs to still contain a hostname,
         - even though this hostname will never be used. -}
        dummy = Param "dummy:"
index 99b774221d0ec24d62737c4c4c18b05f0ae3d8f1..2fcb965a291d33c40016292348b18f73897ab92f 100644 (file)
@@ -205,7 +205,7 @@ rsyncSetup _ mu _ c gc = do
        (c', _encsetup) <- encryptionSetup c gc
 
        -- The rsyncurl is stored in git config, not only in this remote's
-       -- persistant state, so it can vary between hosts.
+       -- persistent state, so it can vary between hosts.
        gitConfigSpecialRemote u c' [("rsyncurl", url)]
        return (c', u)
 
@@ -283,7 +283,7 @@ removeGeneric o includes = do
        ps <- sendParams
        opts <- rsyncOptions o
        ok <- withRsyncScratchDir $ \tmp -> liftIO $ do
-               {- Send an empty directory to rysnc to make it delete. -}
+               {- Send an empty directory to rsync to make it delete. -}
                rsync $ opts ++ ps ++
                        map (\s -> Param $ "--include=" ++ s) includes ++
                        [ Param "--exclude=*" -- exclude everything else
index 97219dd5099f51c82a4f16189ff07ea97d4e51ff..861b5d20d3d30546447d651a205918375c10acc4 100644 (file)
@@ -868,7 +868,7 @@ giveupS3HandleProblem S3HandleNeedCreds u = do
        warning $ needS3Creds u
        giveup "No S3 credentials configured"
 giveupS3HandleProblem S3HandleAnonymousOldAws _ =
-       giveup "This S3 special remote is configured with signature=anonymous, but git-annex is buit with too old a version of the aws library to support that."
+       giveup "This S3 special remote is configured with signature=anonymous, but git-annex is built with too old a version of the aws library to support that."
 
 {- Prepares a S3Handle for later use. Does not connect to S3 or do anything
  - else expensive. -}
index d48c2353d6f208e5456ac7f3d6da02c8dcf2d7ca..518e14bfd12cd83b68015bca5031d5f2a60398da 100644 (file)
@@ -237,7 +237,7 @@ removeExportDav hdl _k loc = case exportLocation loc of
        Right p -> withDavHandle hdl $ \h -> runExport h $ \_dav ->
                removeHelper p
        -- When the exportLocation is not legal for webdav,
-       -- the content is certianly not stored there, so it's ok for
+       -- the content is certainly not stored there, so it's ok for
        -- removal to succeed. This allows recovery after failure to store
        -- content there, as the user can rename the problem file and
        -- this will be called to make sure it's gone.
index c8b84355896ec2bd6877ae709bcd9beb26faae89..e836acd8a9a1f23e87a4bb2a2287ae6f1fd152f8 100644 (file)
@@ -66,7 +66,7 @@ keyTmpLocation = tmpLocation . fromRawFilePath . keyFile
  -
  - This could be just the keyTmpLocation, but when the file is in a
  - subdirectory, the temp file is put in there. Partly this is to keep
- - it close to the final destination; also certian webdav servers
+ - it close to the final destination; also certain webdav servers
  - seem to be buggy when renaming files from the root into a subdir, 
  - and so writing to the subdir avoids such problems.
  -}
index e7d83f8b031e6c1022bd8c41f02e8bc3ea370fad..d366c08e7e6f54b5b054e72db0b956f91c2704f9 100644 (file)
@@ -42,7 +42,7 @@ checkShouldFetch gc transporthandle shas
        | remoteAnnexPull gc = checkNewShas transporthandle shas
        | otherwise = return False
 
--- Check if any of the shas are actally new in the local git repo,
+-- Check if any of the shas are actually new in the local git repo,
 -- to avoid unnecessary fetching.
 checkNewShas :: TransportHandle -> [Git.Sha] -> IO Bool
 checkNewShas transporthandle = check
index 8b31ca16e932381f3335dd783817ed01720c05f0..1b5f8e0a8bc6846ca0cce1bf6fb15c4a6c18949e 100644 (file)
@@ -51,7 +51,7 @@ data Emitted
        | WARNING RemoteURI String
        deriving (Show)
 
--- Messages that the deamon consumes.
+-- Messages that the daemon consumes.
 data Consumed
        = PAUSE
        | LOSTNET
--- a/Limit.hs
+++ b/Limit.hs
@@ -283,7 +283,7 @@ matchLockStatus wantlocked (MatchingInfo p) =
 matchLockStatus _ (MatchingUserInfo _) = pure False
 
 {- Adds a limit to skip files not believed to be present
- - in a specfied repository. Optionally on a prior date. -}
+ - in a specified repository. Optionally on a prior date. -}
 addIn :: String -> Annex ()
 addIn s = do
        u <- Remote.nameToUUID name
index f56503286019934fa28b14ef871ec387864c1aaf..c7981445df244ae5e86f75861357c1f3cb70a1fa 100644 (file)
@@ -5,7 +5,7 @@
  -
  - It's possible for a single object to be stored multiple times on the
  - same remote using different chunk sizes. So, while this is a MapLog, it
- - is not a normal UUIDBased log. Intead, it's a map from UUID and chunk
+ - is not a normal UUIDBased log. Instead, it's a map from UUID and chunk
  - size to number of chunks.
  -
  - Format: "timestamp uuid:chunksize chunkcount"
index ced6341a0ad87fd4a3ff5e59faa35a85c136d600..839bd1b0c0d98170d6cf8f5559d229b2cc3548e8 100644 (file)
@@ -106,7 +106,7 @@ recordExportUnderway remoteuuid ec = do
 
 -- Record information about the export to the git-annex branch.
 --
--- This is equivilant to recordExportBeginning followed by
+-- This is equivalent to recordExportBeginning followed by
 -- recordExportUnderway, but without the ability to clean up from
 -- interrupted exports.
 recordExport :: UUID -> Git.Ref -> ExportChange -> Annex ()
index ea023528fbf996d29cb55dd0da8854b1a36c083f..f5c5be755fceaad6c19f5b31af4ddf20533ba90d 100644 (file)
@@ -33,7 +33,7 @@ import qualified Data.Attoparsec.ByteString.Lazy as A
 import qualified Data.Attoparsec.ByteString.Char8 as A8
 import Data.ByteString.Builder
 
--- This constuctor is not itself exported to other modules, to enforce
+-- This constructor is not itself exported to other modules, to enforce
 -- consistent use of exportedTreeishes.
 data Exported = Exported
        { exportedTreeish :: Git.Ref
index 278430a0b9c0f780bfd456cd1a12220b36d057f9..d7d7c26da82cb3aba50d7a57163d0d6a97a0713c 100644 (file)
@@ -4,7 +4,7 @@
  - be union merged.
  -
  - The old format looks like: "UUID[ INFO[ timestamp=foo]]"
- - The timestamp is last for backwards compatability reasons,
+ - The timestamp is last for backwards compatibility reasons,
  - and may not be present on very old log lines.
  -
  - New uuid based logs instead use the form: "timestamp UUID INFO"
index 0fdec4c0d42cf109c179168b7150ff0442e71394..6bb1011e8449f2c776c34c704e7df056dbcf3af8 100644 (file)
@@ -5,7 +5,7 @@
  - The format: "int key timestamp"
  -
  - The int is a short, stable identifier that the user can use to
- - refer to this key. (Equivilant to a filename.)
+ - refer to this key. (Equivalent to a filename.)
  -
  - The timestamp indicates when the key was first determined to be unused.
  - Older versions of the log omit the timestamp.
index f261862aced985d5db5a7b92b19856e31f7fd8eb..f19f0973f5527f91f9009d686d1efc4412fcfa5a 100644 (file)
@@ -136,7 +136,7 @@ showSideAction m = Annex.getState Annex.output >>= go
 showStoringStateAction :: Annex ()
 showStoringStateAction = showSideAction "recording state in git"
 
-{- Performs an action, supressing showSideAction messages. -}
+{- Performs an action, suppressing showSideAction messages. -}
 doQuietSideAction :: Annex a -> Annex a
 doQuietSideAction = doSideAction' InBlock
 
index a75a6e6b1a27f100c7bb4758ef3444371f065cf9..5804bab08685dc281ccc01d00bd8c47183769486 100644 (file)
@@ -263,7 +263,7 @@ data LocalF c
        -- so, terminate the protocol connection.
        --
        -- If the validity check is provided and fails, the content was
-       -- changed while it was being sent, so verificiation of the
+       -- changed while it was being sent, so verification of the
        -- received content should be forced.
        --
        -- Note: The ByteString may not contain the entire remaining content
@@ -387,7 +387,7 @@ serverLoop a = do
                -- gives up, since it's not clear what state the client
                -- is in, and so not possible to recover.
                Just (ERROR _) -> return Nothing
-               -- When the client sends an unparseable message, the server
+               -- When the client sends an unparsable message, the server
                -- responds with an error message, and loops. This allows
                -- expanding the protocol with new messages.
                Nothing -> do
index f6cdbcf697ff00f8e05e02c5fb3fe37e60bc6b69..ac7e4b4712226b2ac231c16dfb1db7d2c76b3892 100644 (file)
diff --git a/Test.hs b/Test.hs
index 8f85c0bac2e96b44d38105efa51a2f6c63b98a1b..1a2a0d219fa2112372f888963b697fd0552fed59 100644 (file)
--- a/Test.hs
+++ b/Test.hs
@@ -1164,7 +1164,7 @@ test_info = intmpclonerepo $ do
        isjson
        readonly_query isjson
        -- When presented with an input that it does not support,
-       -- info does not stop but processess subsequent inputs too.
+       -- info does not stop but processes subsequent inputs too.
        git_annex'' (const True)
                (sha1annexedfile `isInfixOf`)
                "info"
@@ -1837,7 +1837,7 @@ test_crypto = do
        testscheme scheme = Utility.Tmp.Dir.withTmpDir "gpgtmp" $ \gpgtmp -> do
                -- Use the system temp directory as gpg temp directory because 
                -- it needs to be able to store the agent socket there,
-               -- which can be problimatic when testing some filesystems.
+               -- which can be problematic when testing some filesystems.
                absgpgtmp <- fromRawFilePath <$> absPath (toRawFilePath gpgtmp)
                res <- testscheme' scheme absgpgtmp
                -- gpg may still be running and would prevent
index 8653dca1be41f62e8e5bcd69741f9c2c205c8327..7c2316c238e1f604c8aa42282d1c6551d48c7509 100644 (file)
@@ -724,7 +724,7 @@ runFakeSsh (_host:cmd:[]) =
                \_ _ _ pid -> exitWith =<< waitForProcess pid
 runFakeSsh ps = error $ "fake ssh option parse error: " ++ show ps
 
-{- Tests each TestTree in parallel, and exits with succcess/failure.
+{- Tests each TestTree in parallel, and exits with success/failure.
  -
  - Tasty supports parallel tests, but this does not use it, because
  - many tests need to be run in test repos, and chdir would not be 
index ae45f3a744564ce23f7df8eedcc216b1c24532d3..46fbea912af397c7d8ea7d75b900353accaf28bf 100644 (file)
@@ -23,7 +23,7 @@ data BackendA a = Backend
        , verifyKeyContent :: Maybe (Key -> RawFilePath -> a Bool)
        -- Incrementally verifies the content of a key, using the same
        -- hash as verifyKeyContent, but with the content provided
-       -- incrementally a peice at a time, until finalized.
+       -- incrementally a piece at a time, until finalized.
        , verifyKeyContentIncrementally :: Maybe (Key -> a IncrementalVerifier)
        -- Checks if a key can be upgraded to a better form.
        , canUpgradeKey :: Maybe (Key -> Bool)
index 754fb71a7d60ca741d19e55079a32430b119946d..0617dc22a1b9e519b7672472bd3fe4b8d210d623 100644 (file)
@@ -34,9 +34,9 @@ import Prelude
 -- Describes differences from the v5 repository format.
 --
 -- The serialization is stored in difference.log, so avoid changes that
--- would break compatability.
+-- would break compatibility.
 --
--- Not breaking compatability is why a list of Differences is used, rather
+-- Not breaking compatibility is why a list of Differences is used, rather
 -- than a record type. With a record type, adding a new field for some future
 -- difference would serialize to a value that an older version could not
 -- parse, even if that new field was not used. With the Differences list,
index 005934b9ee6098d7ac11a430f1fd87d91c51a9e7..bc94b168450ce55e502a699888c002715eb87ecf 100644 (file)
@@ -98,7 +98,7 @@ data MatchFiles a = MatchFiles
 type FileMatcher a = Matcher (MatchFiles a)
 
 -- This is a matcher that can have tokens added to it while it's being
--- built, and once complete is compiled to an unchangable matcher.
+-- built, and once complete is compiled to an unchangeable matcher.
 data ExpandableMatcher a
        = BuildingMatcher [Token (MatchFiles a)]
        | CompleteMatcher (Matcher (MatchFiles a))
index c7add2610cdb2592185a24559976a334cf420f78..db5b25d39f85a4c07cc29307875160b3f7e16e56 100644 (file)
@@ -58,7 +58,7 @@ data ImportableContents info = ImportableContents
        { importableContents :: [(ImportLocation, info)]
        , importableHistory :: [ImportableContents info]
        -- ^ Used by remotes that support importing historical versions of
-       -- files that are stored in them. This is equivilant to a git
+       -- files that are stored in them. This is equivalent to a git
        -- commit history.
        --
        -- When retrieving a historical version of a file,
index 121d4fd5cdbdcef1c9740794bcf463b8c7678b07..52b5adab6b6fbe1fee9c19838ccab11728c92bff 100644 (file)
@@ -137,7 +137,7 @@ data RemoteA a = Remote
        , getRepo :: a Git.Repo
        -- a Remote's configuration from git
        , gitconfig :: RemoteGitConfig
-       -- a Remote can be assocated with a specific local filesystem path
+       -- a Remote can be associated with a specific local filesystem path
        , localpath :: Maybe FilePath
        -- a Remote can be known to be readonly
        , readonly :: Bool
index 49665e87730d67db258d7088b509e4791a7c1018..c807b29d9e19e43884adbe04944f318b19467443 100644 (file)
@@ -40,7 +40,7 @@ setIndirect = do
        coreworktree = ConfigKey "core.worktree"
        indirectworktree = ConfigKey "core.indirect-worktree"
        setbare = do
-               -- core.worktree is not compatable with
+               -- core.worktree is not compatible with
                -- core.bare; git does not allow both to be set, so
                -- unset it when enabling direct mode, caching in
                -- core.indirect-worktree
index 1a09cb310b57f0fd89941a062a5d96e3b24882e1..fec056e3bce21f8e26430123049fc59e01e5f314 100644 (file)
@@ -19,7 +19,7 @@ import Data.ByteString.UTF8 (fromString, toString)
 import Data.Char
 
 -- | This uses the FileSystemEncoding, so it can be used on Strings
--- that repesent filepaths containing arbitrarily encoded characters.
+-- that represent filepaths containing arbitrarily encoded characters.
 toB64 :: String -> String
 toB64 = toString . B64.encode . encodeBS
 
index 45937e32d63ebd8e336637fdb1bae7c39d7cb4da..e8afb2c1bd1e61f110b5e2f3e2b07403c2e4bb78 100644 (file)
@@ -1,4 +1,4 @@
-{- bloomfilter compatability wrapper
+{- bloomfilter compatibility wrapper
  -
  - Copyright 2014 Joey Hess <id@joeyh.name>
  -
index 3a0cc5baebf63a348c91b8302c4279a8f92fc2d3..6676ed4e3d639e51ae223fcc9a73ad90eaabe3e1 100644 (file)
@@ -67,7 +67,7 @@ daemonize cmd params openlogfd pidfile changedirectory a = do
        envvar = "DAEMONIZED"
 #endif
 
-{- To run an action that is normally daemonized in the forground. -}
+{- To run an action that is normally daemonized in the foreground. -}
 #ifndef mingw32_HOST_OS
 foreground :: IO Fd -> Maybe FilePath -> IO () -> IO ()
 foreground openlogfd pidfile a = do
index 64c01d95704935a33c325674e77f4bc586f1f817..8d910c61894f67d06cc057118d2b9ec621265713 100644 (file)
@@ -21,7 +21,7 @@
  - error. This was bad.
  -
  - So, a committee was formed. And it arrived at a committee-like decision,
- - which satisfied noone, confused everyone, and made the world an uglier
+ - which satisfied no one, confused everyone, and made the world an uglier
  - place. As with all committees, this was meh. Or in this case, "mib".
  -
  - And the drive manufacturers happily continued selling drives that are
@@ -82,7 +82,7 @@ storageUnits =
        , Unit (p 4) "TB" "terabyte"
        , Unit (p 3) "GB" "gigabyte"
        , Unit (p 2) "MB" "megabyte"
-       , Unit (p 1) "kB" "kilobyte" -- weird capitalization thanks to committe
+       , Unit (p 1) "kB" "kilobyte" -- weird capitalization thanks to committee
        , Unit 1 "B" "byte"
        ]
   where
@@ -122,7 +122,7 @@ bandwidthUnits =
        , Unit (p 4) "Tbit" "terabit"
        , Unit (p 3) "Gbit" "gigabit"
        , Unit (p 2) "Mbit" "megabit"
-       , Unit (p 1) "kbit" "kilobit" -- weird capitalization thanks to committe
+       , Unit (p 1) "kbit" "kilobit" -- weird capitalization thanks to committee
        ]
   where
        p :: Integer -> Integer
index 107b73e8fbe19558dc373c3206951f483cb7579c..fdb3b712cce262f3c9c284b1f7c8284c2251ec9d 100644 (file)
@@ -52,7 +52,7 @@ watchDir dir ignored scanevents hooks = do
                                        else maybe (runhook delHook Nothing) handleadd
                                                =<< getstatus (eventPath evt)
                        {- Add hooks are run when a file is modified for 
-                        - compatability with INotify, which calls the add
+                        - compatibility with INotify, which calls the add
                         - hook when a file is closed, and so tends to call
                         - both add and modify for file modifications. -}
                        when (hasflag eventFlagItemModified && not (hasflag eventFlagItemIsDir)) $ do
index 0b02053c9a2ef6010aa75a86502a0bc17e59da24..eaff7f95ff88d6e35622820f95b71cb51375ff32 100644 (file)
@@ -33,7 +33,7 @@ watchDir dir ignored scanevents hooks = do
                        (Modified _ _)
                                | isDirectory evt -> noop
                                {- Add hooks are run when a file is modified for 
-                                - compatability with INotify, which calls the add
+                                - compatibility with INotify, which calls the add
                                 - hook when a file is closed, and so tends to call
                                 - both add and modify for file modifications. -}
                                | otherwise -> do
index ccbf23be08ad5d95097318598eff030f7a908386..835409f482b5b1849b4044acfca8349366f52662 100644 (file)
@@ -284,7 +284,7 @@ props_macs_stable = map (\(desc, mac, result) -> (desc ++ " stable", calcMac mac
 
 data IncrementalHasher = IncrementalHasher
        { updateIncrementalHasher :: S.ByteString -> IO ()
-       -- ^ Called repeatedly on each peice of the content.
+       -- ^ Called repeatedly on each piece of the content.
        , finalizeIncrementalHasher :: IO (Maybe String)
        -- ^ Called once the full content has been sent, returns
        -- the hash. (Nothing if unableIncremental was called.)
index 2e3c525815e56d2c436cf45ef6bc55ee5cd12e6b..e050ff7dd36e8aa7c209b3454665cb4d10b5f049 100644 (file)
@@ -48,7 +48,7 @@ isHtmlBs = isHtml . B8.unpack
 
 -- | Check if the file is html.
 --
--- It would be equivilant to use isHtml <$> readFile file,
+-- It would be equivalent to use isHtml <$> readFile file,
 -- but since that would not read all of the file, the handle
 -- would remain open until it got garbage collected sometime later.
 isHtmlFile :: FilePath -> IO Bool
index 9c683181bf89af220ea7b96723a993c2f9c86915..66e00a47befb2a3b659da14de48db063a0aed0eb 100644 (file)
@@ -53,13 +53,13 @@ isLoopbackAddress :: SockAddr -> Bool
 isLoopbackAddress (SockAddrInet _ ipv4) = case hostAddressToTuple ipv4 of
        -- localhost
        (127,_,_,_) -> True
-       -- current network; functions equivilant to loopback
+       -- current network; functions equivalent to loopback
        (0,_,_, _) -> True
        _ -> False
 isLoopbackAddress (SockAddrInet6 _ _ ipv6 _) = case hostAddress6ToTuple ipv6 of
        -- localhost
        (0,0,0,0,0,0,0,1) -> True
-       -- unspecified address; functions equivilant to loopback
+       -- unspecified address; functions equivalent to loopback
        (0,0,0,0,0,0,0,0) -> True
        v -> maybe False
                (isLoopbackAddress . SockAddrInet 0)
index a9a6bb1906340ebd5b4e2eb37e432cbbd2809a8f..6f07059f53cd79dd581e9ebf296676bb48894a84 100644 (file)
@@ -131,7 +131,7 @@ replaceInode :: FileID -> InodeCache -> InodeCache
 replaceInode inode (InodeCache (InodeCachePrim _ sz mtime)) =
        InodeCache (InodeCachePrim inode sz mtime)
 
-{- For backwards compatability, support low-res mtime with no
+{- For backwards compatibility, support low-res mtime with no
  - fractional seconds. -}
 data MTime = MTimeLowRes EpochTime | MTimeHighRes POSIXTime
        deriving (Show, Ord)
@@ -249,7 +249,7 @@ data SentinalStatus = SentinalStatus
  - On Windows, time stamp differences are ignored, since they change
  - with the timezone.
  -
- - When the sential file does not exist, InodeCaches canot reliably be
+ - When the sential file does not exist, InodeCaches cannot reliably be
  - compared, so the assumption is that there is has been a change.
  -}
 checkSentinalFile :: SentinalFile -> IO SentinalStatus
index 68d1ded506e96c16ecd173492dbe2d974b044a20..3b8e0dc02e59b4c838f39e02be2e141ad30d4b8c 100644 (file)
@@ -81,7 +81,7 @@ dropLock :: LockHandle -> IO ()
 dropLock = closeHandle
 
 {- If the initial lock fails, this is a BUSY wait, and does not
- - guarentee FIFO order of waiters. In other news, Windows is a POS. -}
+ - guarantee FIFO order of waiters. In other news, Windows is a POS. -}
 waitToLock :: IO (Maybe lockhandle) -> IO lockhandle
 waitToLock locker = takelock
   where
index ddb0b92291b7053b9f16ce52030c2db3682ef720..87f1f1a21488d52d053d0a008f4c6623289c07af 100644 (file)
@@ -39,7 +39,7 @@ import Prelude
 -- or the Seconds timeout if the pid lock is held by another process.
 --
 -- There are two levels of locks. A STM lock is used to handle
--- fine-grained locking amoung threads, locking a specific lockfile,
+-- fine-grained locking among threads, locking a specific lockfile,
 -- but only in memory. The pid lock handles locking between processes.
 --
 -- The pid lock is only taken once, and LockShared is used for it,
index b81fbdf07465fda6b756e9dffe81aa264e116500..3ea3da836705c07c162d3a351ef70a844c7512a3 100644 (file)
@@ -38,7 +38,7 @@ lockExclusive file = fmap fst <$> tryMakeLockHandle P.lockPool file
        (\f _ -> fmap mk <$> F.lockExclusive f)
 
 {- If the initial lock fails, this is a BUSY wait, and does not
- - guarentee FIFO order of waiters. In other news, Windows is a POS. -}
+ - guarantee FIFO order of waiters. In other news, Windows is a POS. -}
 waitToLock :: IO (Maybe lockhandle) -> IO lockhandle
 waitToLock = F.waitToLock
 
index 567522b59e015a609b68e3ce301b765547bf147a..0fbcd0104190b0c8cc1a4a849456f9bd4c03827a 100644 (file)
@@ -37,7 +37,7 @@ import Common
 import Data.Kind
 
 {- A Token can be an Operation of an arbitrary type, or one of a few
- - predefined peices of syntax. -}
+ - predefined pieces of syntax. -}
 data Token op = Operation op | And | Or | Not | Open | Close
        deriving (Show, Eq)
 
index 121c06e7cd3cdd24367cb3a09053dd64391100c9..3cf527547bb39088fcabdeb10bdb20ed08531505 100644 (file)
@@ -94,7 +94,7 @@ prop_segment_regressionTest :: Bool
 prop_segment_regressionTest = all id
        -- Even an empty list is a segment.
        [ segment (== "--") [] == [[]]
-       -- There are two segements in this list, even though the first is empty.
+       -- There are two segments in this list, even though the first is empty.
        , segment (== "--") ["--", "foo", "bar"] == [[],["foo","bar"]]
        ]
 
index b5aeb16fd00fcecd1dcb0cda53aac7bd4afc817c..dcb21400eabc87d35f3c75efe2236aab2ddf0ecc 100644 (file)
@@ -53,7 +53,7 @@ import Utility.FileSystemEncoding
  -
  - This does not guarantee that two paths that refer to the same location,
  - and are both relative to the same location (or both absolute) will
- - yeild the same result. Run both through normalise from System.RawFilePath
+ - yield the same result. Run both through normalise from System.RawFilePath
  - to ensure that.
  -}
 simplifyPath :: RawFilePath -> RawFilePath
@@ -90,7 +90,7 @@ upFrom dir
 
 {- Checks if the first RawFilePath is, or could be said to contain the second.
  - For example, "foo/" contains "foo/bar". Also, "foo", "./foo", "foo/" etc
- - are all equivilant.
+ - are all equivalent.
  -}
 dirContains :: RawFilePath -> RawFilePath -> Bool
 dirContains a b = a == b
index 857dd5e3200e0dd415920c8c122292525cd64b6b..4007fbbb0fc1ddbdbf48f85625d1f09ad76bbb62 100644 (file)
@@ -37,7 +37,7 @@ import Utility.FileSystemEncoding
  - Also simplifies it using simplifyPath.
  -
  - The first parameter is a base directory (ie, the cwd) to use if the path
- - is not already absolute, and should itsef be absolute.
+ - is not already absolute, and should itself be absolute.
  -
  - Does not attempt to deal with edge cases or ensure security with
  - untrusted inputs.
index d55c447b691b287287f92efe6f4ad10f66d504ee..b7ec0f1d3c12deb519fd282e34cbbf3333de5974 100644 (file)
@@ -352,7 +352,7 @@ contentDispositionFilename s
 headRequest :: Request -> Request
 headRequest r = r
        { method = methodHead
-       -- remove defaut Accept-Encoding header, to get actual,
+       -- remove default Accept-Encoding header, to get actual,
        -- not gzip compressed size.
        , requestHeaders = (hAcceptEncoding, B.empty) :
                filter (\(h, _) -> h /= hAcceptEncoding)
index d35391252d0b12a6d88ffac4410d3c10fe92d362..5acbdee99cd683142d0c35e53544ac442c7894fb 100644 (file)
@@ -1,6 +1,6 @@
 {- Yesod stuff, that's typically found in the scaffolded site.
  -
- - Also a bit of a compatability layer for older versions of yesod.
+ - Also a bit of a compatibility layer for older versions of yesod.
  -
  - Copyright 2012-2014 Joey Hess <id@joeyh.name>
  -
index a8390321efba14bccef254a99dbb2fffb5f5c2c8..12fdcbd27cb84d0b1e6b8f3a4dfe95adc0ec5938 100755 (executable)
@@ -4,7 +4,7 @@
 # 
 # This is only a convenience script to avoid the user needing to type much
 # in termux. The standalone tarball automatically adapts itself to the termux
-# environment, so this script should stay as mininal as possible.
+# environment, so this script should stay as minimal as possible.
 #
 # This script needs to be sourced into the current termux shell, rather
 # than run with a new shell, so it can set the PATH to include git-annex.
index 87f78f71897bf4b919f171224143e8fe9a3d6cfd..5ebc664c810e2df58ce3a593b94af548e6d73a26 100644 (file)
@@ -30,7 +30,7 @@ Description:
  to git and transferring them to other computers. The git-annex webapp
  makes it easy to set up and use git-annex this way.
 -- The tarball uploaded to hackage does not include every non-haskell
--- file in the git repo. The website is left out, so is build machinary for
+-- file in the git repo. The website is left out, so is build machinery for
 -- standalone apps, and packages. Include only files that are needed
 -- make cabal install git-annex work.
 Extra-Source-Files:
@@ -397,7 +397,7 @@ Executable git-annex
   else
     GHC-Options: -O0
 
-  -- Avoid linking with unused dynamic libaries.
+  -- Avoid linking with unused dynamic libraries.
   if os(linux) || os(freebsd)
     GHC-Options: -optl-Wl,--as-needed
 
index e17cb4580c3a7f315c911a917da5df94964bec71..ec4087453a86bc310318c155d0d97d8037a9f691 100644 (file)
@@ -4,7 +4,7 @@
       Adding an Internet Archive item
     <p>
       <a href="http://archive.org/">The Internet Archive</a> allows anyone #
-      to publically archive their information, for free. All you need to #
+      to publicly archive their information, for free. All you need to #
       get started is to #
       <a href="http://archive.org/account/login.createaccount.php">
         Create an account